@@ -20,6 +20,7 @@ class AsyncZipper(Thread):
         self._file_path = file_path
         self._zipped_file_path = file_path + '.gz'
         self._upload = Upload.get(Upload.file_path == file_path)
+        assert self._upload is not None
         self._initial_substatus = self._upload.substatus
         self._logger = get_oort_logger('uploader', debug=debug)
 
@@ -28,7 +29,7 @@ class AsyncZipper(Thread):
         return f'[AsyncZipper: {self._file_path}]'
 
     def run(self):
-        self._upload = self._upload.smart_update(substatus=Substatus.ZIPPING.value)
+        self._upload.smart_update(substatus=Substatus.ZIPPING.value)
         self._logger.info(f'{self.log_prefix} Starting to gzip file: {self._file_path}...')
         # Make file read-only to avoid deletion until end
         os.chmod(self._file_path, S_IREAD | S_IRGRP | S_IROTH)
@@ -55,7 +56,7 @@ class AsyncZipper(Thread):
             # Deleting original file
             pathlib.Path(self._file_path).unlink()
             # Back to upload pending status.
-            self._upload = self._upload.smart_update(substatus=Substatus.PENDING.value)
+            self._upload.smart_update(substatus=Substatus.PENDING.value)
             self._logger.info(f'{self.log_prefix} Done with gzip of file: {self._file_path}...')
             time.sleep(0.1)
 
